Documentation Site
The documentation site is built with Antora and the Feel++ Antora UI bundle.
Local Build
npm install
npm run docs:build
The site is generated in build/site.
Preview locally with:
npm run docs:preview
The documentation site is built with Antora and the Feel++ Antora UI bundle.
npm install
npm run docs:build
The site is generated in build/site.
Preview locally with:
npm run docs:preview